@@ -17,7 +17,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Pin::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.460';
+$VERSION = '3.480';
 
 structs('_new_base',
 	'Verilog::Netlist::Pin::Struct'
@@ -53,7 +53,10 @@ sub new {
     } elsif (defined $params{pinselects}) {
 	# remap pinselects to _pinselects
 	foreach my $pinselect (@{$params{pinselects}}) {
-	    push(@{$params{_pinselects}}, new Verilog::Netlist::PinSelection($pinselect->{netname}, $pinselect->{msb}, $pinselect->{lsb}));
+	    push @{$params{_pinselects}},
+		new Verilog::Netlist::PinSelection($pinselect->{netname},
+						   $pinselect->{msb},
+						   $pinselect->{lsb});
 	}
 	delete $params{pinselects};
     }
@@ -86,11 +89,12 @@ sub delete {
 # Legacy accessors
 sub netname {
     return undef if !defined($_[0]->_pinselects);
-    return @{$_[0]->_pinselects}[0]->{netname};
+    return @{$_[0]->_pinselects}[0]->{_netname};
 }
 sub net {
     my $nets = $_[0]->_nets;
     return undef if !defined($nets);
+    return undef if !@{$nets}[0];
     return @{$nets}[0]->{net};
 }
 
@@ -327,13 +331,13 @@ instead.
 
 =item $self->nets
 
-Array of references to the Verilog::Netlist::Net the pin connects to.  Only
-valid after a link.
+Array of hashes the pin connects to.  Each hash contains a msb, lsb, and
+net (a Verilog::Netlist::Net).  Only valid after a link.
 
 =item $self->nets_sorted
 
-Array of sorted references to the Verilog::Netlist::Net the pin connects
-to.  Only valid after a link.
+Array of sorted hashes the pin connects to.  Each hash contains a msb, lsb,
+and net (a Verilog::Netlist::Net).  Only valid after a link.
 
 =item $self->netlist
 
@@ -376,11 +380,11 @@ Prints debugging information for this pin.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<https://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<https://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2019 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2022 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
@@ -391,7 +395,8 @@ Wilson Snyder <wsnyder@wsnyder.org>
 =head1 SEE ALSO
 
 L<Verilog-Perl>,
-L<Verilog::Netlist::Subclass>
-L<Verilog::Netlist>
+L<Verilog::Netlist::Subclass>,
+L<Verilog::Netlist>,
+L<Verilog::Netlist::PinSelection>
 
 =cut
